/* Copyright (C) 2007 Brian Aker, TangentOrg

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 of the License.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#ifdef USE_PRAGMA_INTERFACE
#pragma interface			/* gcc class implementation */
#endif

/** @brief
  SKELETON_SHARE is a structure that will be shared among all open handlers.
  This skeleton implements the minimum of what you will probably need.
*/
typedef struct st_skeleton_share {
  char *table_name;
  uint table_name_length,use_count;
  pthread_mutex_t mutex;
  THR_LOCK lock;
} SKELETON_SHARE;

class ha_skeleton: public handler
{
  THR_LOCK_DATA lock;      ///< MySQL lock
  SKELETON_SHARE *share;    ///< Shared lock info

public:
  ha_skeleton(handlerton *hton, TABLE_SHARE *table_arg);
  ~ha_skeleton()
  {
  }

  const char *table_type() const { return "SKELETON"; }

  const char *index_type(uint inx) { return "NONE"; }

  const char **bas_ext() const;

  ulonglong table_flags() const { return 0; }

  ulong index_flags(uint inx, uint part, bool all_parts) const { return 0; }

  int open(const char *name, int mode, uint test_if_locked);    // required
  int close(void);                                              // required
  int rnd_init(bool scan);                                      //required
  int rnd_next(byte *buf);                                      ///< required
  int rnd_pos(byte * buf, byte *pos);                           ///< required
  void position(const byte *record);                            ///< required
  int info(uint);                                               ///< required
  int create(const char *name, TABLE *form,
             HA_CREATE_INFO *create_info);                      ///< required

  THR_LOCK_DATA **store_lock(THD *thd, THR_LOCK_DATA **to,
                             enum thr_lock_type lock_type);     ///< required
};
